Class: Google::Apis::TranslateV3::Dataset
- Inherits:
-
Object
- Object
- Google::Apis::TranslateV3::Dataset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/translate_v3/classes.rb,
lib/google/apis/translate_v3/representations.rb,
lib/google/apis/translate_v3/representations.rb
Overview
A dataset that hosts the examples (sentence pairs) used for translation models.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
The name of the dataset to show in the interface.
-
#example_count ⇒ Fixnum
Output only.
-
#name ⇒ String
The resource name of the dataset, in form of
projects/project-number-or-id/ locations/location_id/datasets/dataset_id`Corresponds to the JSON propertyname`. -
#source_language_code ⇒ String
The BCP-47 language code of the source language.
-
#target_language_code ⇒ String
The BCP-47 language code of the target language.
-
#test_example_count ⇒ Fixnum
Output only.
-
#train_example_count ⇒ Fixnum
Output only.
-
#update_time ⇒ String
Output only.
-
#validate_example_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Dataset
constructor
A new instance of Dataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Dataset
Returns a new instance of Dataset.
550 551 552 |
# File 'lib/google/apis/translate_v3/classes.rb', line 550 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this dataset was created.
Corresponds to the JSON property createTime
500 501 502 |
# File 'lib/google/apis/translate_v3/classes.rb', line 500 def create_time @create_time end |
#display_name ⇒ String
The name of the dataset to show in the interface. The name can be up to 32
characters long and can consist only of ASCII Latin letters A-Z and a-z,
underscores (_), and ASCII digits 0-9.
Corresponds to the JSON property displayName
507 508 509 |
# File 'lib/google/apis/translate_v3/classes.rb', line 507 def display_name @display_name end |
#example_count ⇒ Fixnum
Output only. The number of examples in the dataset.
Corresponds to the JSON property exampleCount
512 513 514 |
# File 'lib/google/apis/translate_v3/classes.rb', line 512 def example_count @example_count end |
#name ⇒ String
The resource name of the dataset, in form of projects/project-number-or-id/
locations/location_id/datasets/dataset_id`
Corresponds to the JSON propertyname`
518 519 520 |
# File 'lib/google/apis/translate_v3/classes.rb', line 518 def name @name end |
#source_language_code ⇒ String
The BCP-47 language code of the source language.
Corresponds to the JSON property sourceLanguageCode
523 524 525 |
# File 'lib/google/apis/translate_v3/classes.rb', line 523 def source_language_code @source_language_code end |
#target_language_code ⇒ String
The BCP-47 language code of the target language.
Corresponds to the JSON property targetLanguageCode
528 529 530 |
# File 'lib/google/apis/translate_v3/classes.rb', line 528 def target_language_code @target_language_code end |
#test_example_count ⇒ Fixnum
Output only. Number of test examples (sentence pairs).
Corresponds to the JSON property testExampleCount
533 534 535 |
# File 'lib/google/apis/translate_v3/classes.rb', line 533 def test_example_count @test_example_count end |
#train_example_count ⇒ Fixnum
Output only. Number of training examples (sentence pairs).
Corresponds to the JSON property trainExampleCount
538 539 540 |
# File 'lib/google/apis/translate_v3/classes.rb', line 538 def train_example_count @train_example_count end |
#update_time ⇒ String
Output only. Timestamp when this dataset was last updated.
Corresponds to the JSON property updateTime
543 544 545 |
# File 'lib/google/apis/translate_v3/classes.rb', line 543 def update_time @update_time end |
#validate_example_count ⇒ Fixnum
Output only. Number of validation examples (sentence pairs).
Corresponds to the JSON property validateExampleCount
548 549 550 |
# File 'lib/google/apis/translate_v3/classes.rb', line 548 def validate_example_count @validate_example_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
555 556 557 558 559 560 561 562 563 564 565 566 |
# File 'lib/google/apis/translate_v3/classes.rb', line 555 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @example_count = args[:example_count] if args.key?(:example_count) @name = args[:name] if args.key?(:name) @source_language_code = args[:source_language_code] if args.key?(:source_language_code) @target_language_code = args[:target_language_code] if args.key?(:target_language_code) @test_example_count = args[:test_example_count] if args.key?(:test_example_count) @train_example_count = args[:train_example_count] if args.key?(:train_example_count) @update_time = args[:update_time] if args.key?(:update_time) @validate_example_count = args[:validate_example_count] if args.key?(:validate_example_count) end |