Class: Google::Apis::TranslateV3::DetectLanguageResponse
- Inherits:
-
Object
- Object
- Google::Apis::TranslateV3::DetectLanguageResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/translate_v3/classes.rb,
lib/google/apis/translate_v3/representations.rb,
lib/google/apis/translate_v3/representations.rb
Overview
The response message for language detection.
Instance Attribute Summary collapse
-
#languages ⇒ Array<Google::Apis::TranslateV3::DetectedLanguage>
The most probable language detected by the Translation API.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DetectLanguageResponse
constructor
A new instance of DetectLanguageResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DetectLanguageResponse
Returns a new instance of DetectLanguageResponse.
670 671 672 |
# File 'lib/google/apis/translate_v3/classes.rb', line 670 def initialize(**args) update!(**args) end |
Instance Attribute Details
#languages ⇒ Array<Google::Apis::TranslateV3::DetectedLanguage>
The most probable language detected by the Translation API. For each request,
the Translation API will always return only one result.
Corresponds to the JSON property languages
668 669 670 |
# File 'lib/google/apis/translate_v3/classes.rb', line 668 def languages @languages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
675 676 677 |
# File 'lib/google/apis/translate_v3/classes.rb', line 675 def update!(**args) @languages = args[:languages] if args.key?(:languages) end |