Class: Google::Apis::TranslateV3::DocumentOutputConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/translate_v3/classes.rb,
lib/google/apis/translate_v3/representations.rb,
lib/google/apis/translate_v3/representations.rb

Overview

A document translation request output config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DocumentOutputConfig

Returns a new instance of DocumentOutputConfig.



770
771
772
# File 'lib/google/apis/translate_v3/classes.rb', line 770

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_destinationGoogle::Apis::TranslateV3::GcsDestination

The Google Cloud Storage location for the output content. Corresponds to the JSON property gcsDestination



757
758
759
# File 'lib/google/apis/translate_v3/classes.rb', line 757

def gcs_destination
  @gcs_destination
end

#mime_typeString

Optional. Specifies the translated document's mime_type. If not specified, the translated file's mime type will be the same as the input file's mime type. Currently only support the output mime type to be the same as input mime type.

  • application/pdf - application/vnd.openxmlformats-officedocument. wordprocessingml.document - application/vnd.openxmlformats-officedocument. presentationml.presentation - application/vnd.openxmlformats-officedocument. spreadsheetml.sheet Corresponds to the JSON property mimeType

Returns:

  • (String)


768
769
770
# File 'lib/google/apis/translate_v3/classes.rb', line 768

def mime_type
  @mime_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



775
776
777
778
# File 'lib/google/apis/translate_v3/classes.rb', line 775

def update!(**args)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
end