Class: Google::Apis::TranslateV3::GlossaryTermsPair

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/translate_v3/classes.rb,
lib/google/apis/translate_v3/representations.rb,
lib/google/apis/translate_v3/representations.rb

Overview

Represents a single entry for an unidirectional glossary.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GlossaryTermsPair

Returns a new instance of GlossaryTermsPair.



1197
1198
1199
# File 'lib/google/apis/translate_v3/classes.rb', line 1197

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#source_termGoogle::Apis::TranslateV3::GlossaryTerm

Represents a single glossary term Corresponds to the JSON property sourceTerm



1190
1191
1192
# File 'lib/google/apis/translate_v3/classes.rb', line 1190

def source_term
  @source_term
end

#target_termGoogle::Apis::TranslateV3::GlossaryTerm

Represents a single glossary term Corresponds to the JSON property targetTerm



1195
1196
1197
# File 'lib/google/apis/translate_v3/classes.rb', line 1195

def target_term
  @target_term
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1202
1203
1204
1205
# File 'lib/google/apis/translate_v3/classes.rb', line 1202

def update!(**args)
  @source_term = args[:source_term] if args.key?(:source_term)
  @target_term = args[:target_term] if args.key?(:target_term)
end