Class: Google::Apis::TranslateV3::ListOperationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::TranslateV3::ListOperationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/translate_v3/classes.rb,
lib/google/apis/translate_v3/representations.rb,
lib/google/apis/translate_v3/representations.rb
Overview
The response message for Operations.ListOperations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#operations ⇒ Array<Google::Apis::TranslateV3::Operation>
A list of operations that matches the specified filter in the request.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListOperationsResponse
constructor
A new instance of ListOperationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListOperationsResponse
Returns a new instance of ListOperationsResponse.
1656 1657 1658 |
# File 'lib/google/apis/translate_v3/classes.rb', line 1656 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
1641 1642 1643 |
# File 'lib/google/apis/translate_v3/classes.rb', line 1641 def next_page_token @next_page_token end |
#operations ⇒ Array<Google::Apis::TranslateV3::Operation>
A list of operations that matches the specified filter in the request.
Corresponds to the JSON property operations
1646 1647 1648 |
# File 'lib/google/apis/translate_v3/classes.rb', line 1646 def operations @operations end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable resources. Populated when the request sets
ListOperationsRequest.return_partial_success and reads across collections.
For example, when attempting to list all resources across all supported
locations.
Corresponds to the JSON property unreachable
1654 1655 1656 |
# File 'lib/google/apis/translate_v3/classes.rb', line 1654 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1661 1662 1663 1664 1665 |
# File 'lib/google/apis/translate_v3/classes.rb', line 1661 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @operations = args[:operations] if args.key?(:operations) @unreachable = args[:unreachable] if args.key?(:unreachable) end |