Class: Google::Apis::TranslateV3::Model

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/translate_v3/classes.rb,
lib/google/apis/translate_v3/representations.rb,
lib/google/apis/translate_v3/representations.rb

Overview

A trained translation model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Model

Returns a new instance of Model.



1768
1769
1770
# File 'lib/google/apis/translate_v3/classes.rb', line 1768

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when the model resource was created, which is also when the training started. Corresponds to the JSON property createTime

Returns:

  • (String)


1717
1718
1719
# File 'lib/google/apis/translate_v3/classes.rb', line 1717

def create_time
  @create_time
end

#datasetString

Required. The dataset from which the model is trained, in form of projects/ project-number-or-id/locations/location_id/datasets/dataset_id` Corresponds to the JSON propertydataset`

Returns:

  • (String)


1723
1724
1725
# File 'lib/google/apis/translate_v3/classes.rb', line 1723

def dataset
  @dataset
end

#display_nameString

The name of the model to show in the interface. The name can be up to 32 characters long and can consist only of ASCII Latin letters A-Z and a-z, underscores (_), and ASCII digits 0-9. Corresponds to the JSON property displayName

Returns:

  • (String)


1730
1731
1732
# File 'lib/google/apis/translate_v3/classes.rb', line 1730

def display_name
  @display_name
end

#nameString

The resource name of the model, in form of projects/project-number-or-id/ locations/location_id/models/model_id` Corresponds to the JSON propertyname`

Returns:

  • (String)


1736
1737
1738
# File 'lib/google/apis/translate_v3/classes.rb', line 1736

def name
  @name
end

#source_language_codeString

Output only. The BCP-47 language code of the source language. Corresponds to the JSON property sourceLanguageCode

Returns:

  • (String)


1741
1742
1743
# File 'lib/google/apis/translate_v3/classes.rb', line 1741

def source_language_code
  @source_language_code
end

#target_language_codeString

Output only. The BCP-47 language code of the target language. Corresponds to the JSON property targetLanguageCode

Returns:

  • (String)


1746
1747
1748
# File 'lib/google/apis/translate_v3/classes.rb', line 1746

def target_language_code
  @target_language_code
end

#test_example_countFixnum

Output only. Number of examples (sentence pairs) used to test the model. Corresponds to the JSON property testExampleCount

Returns:

  • (Fixnum)


1751
1752
1753
# File 'lib/google/apis/translate_v3/classes.rb', line 1751

def test_example_count
  @test_example_count
end

#train_example_countFixnum

Output only. Number of examples (sentence pairs) used to train the model. Corresponds to the JSON property trainExampleCount

Returns:

  • (Fixnum)


1756
1757
1758
# File 'lib/google/apis/translate_v3/classes.rb', line 1756

def train_example_count
  @train_example_count
end

#update_timeString

Output only. Timestamp when this model was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1761
1762
1763
# File 'lib/google/apis/translate_v3/classes.rb', line 1761

def update_time
  @update_time
end

#validate_example_countFixnum

Output only. Number of examples (sentence pairs) used to validate the model. Corresponds to the JSON property validateExampleCount

Returns:

  • (Fixnum)


1766
1767
1768
# File 'lib/google/apis/translate_v3/classes.rb', line 1766

def validate_example_count
  @validate_example_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
# File 'lib/google/apis/translate_v3/classes.rb', line 1773

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dataset = args[:dataset] if args.key?(:dataset)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @source_language_code = args[:source_language_code] if args.key?(:source_language_code)
  @target_language_code = args[:target_language_code] if args.key?(:target_language_code)
  @test_example_count = args[:test_example_count] if args.key?(:test_example_count)
  @train_example_count = args[:train_example_count] if args.key?(:train_example_count)
  @update_time = args[:update_time] if args.key?(:update_time)
  @validate_example_count = args[:validate_example_count] if args.key?(:validate_example_count)
end