Class: Google::Apis::TranslateV3::TranslateDocumentResponse
- Inherits:
-
Object
- Object
- Google::Apis::TranslateV3::TranslateDocumentResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/translate_v3/classes.rb,
lib/google/apis/translate_v3/representations.rb,
lib/google/apis/translate_v3/representations.rb
Overview
A translated document response message.
Instance Attribute Summary collapse
-
#document_translation ⇒ Google::Apis::TranslateV3::DocumentTranslation
A translated document message.
-
#glossary_config ⇒ Google::Apis::TranslateV3::TranslateTextGlossaryConfig
Configures which glossary is used for a specific target language and defines options for applying that glossary.
-
#glossary_document_translation ⇒ Google::Apis::TranslateV3::DocumentTranslation
A translated document message.
-
#model ⇒ String
Only present when 'model' is present in the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TranslateDocumentResponse
constructor
A new instance of TranslateDocumentResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TranslateDocumentResponse
Returns a new instance of TranslateDocumentResponse.
2338 2339 2340 |
# File 'lib/google/apis/translate_v3/classes.rb', line 2338 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document_translation ⇒ Google::Apis::TranslateV3::DocumentTranslation
A translated document message.
Corresponds to the JSON property documentTranslation
2316 2317 2318 |
# File 'lib/google/apis/translate_v3/classes.rb', line 2316 def document_translation @document_translation end |
#glossary_config ⇒ Google::Apis::TranslateV3::TranslateTextGlossaryConfig
Configures which glossary is used for a specific target language and defines
options for applying that glossary.
Corresponds to the JSON property glossaryConfig
2322 2323 2324 |
# File 'lib/google/apis/translate_v3/classes.rb', line 2322 def glossary_config @glossary_config end |
#glossary_document_translation ⇒ Google::Apis::TranslateV3::DocumentTranslation
A translated document message.
Corresponds to the JSON property glossaryDocumentTranslation
2327 2328 2329 |
# File 'lib/google/apis/translate_v3/classes.rb', line 2327 def glossary_document_translation @glossary_document_translation end |
#model ⇒ String
Only present when 'model' is present in the request. 'model' is normalized to
have a project number. For example: If the 'model' field in
TranslateDocumentRequest is: projects/project-id/locations/location-id/
models/general/nmt then model here would be normalized to projects/
project-number/locations/location-id/models/general/nmt.
Corresponds to the JSON property model
2336 2337 2338 |
# File 'lib/google/apis/translate_v3/classes.rb', line 2336 def model @model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2343 2344 2345 2346 2347 2348 |
# File 'lib/google/apis/translate_v3/classes.rb', line 2343 def update!(**args) @document_translation = args[:document_translation] if args.key?(:document_translation) @glossary_config = args[:glossary_config] if args.key?(:glossary_config) @glossary_document_translation = args[:glossary_document_translation] if args.key?(:glossary_document_translation) @model = args[:model] if args.key?(:model) end |