Class: Google::Apis::TranslateV3::TranslateTextGlossaryConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/translate_v3/classes.rb,
lib/google/apis/translate_v3/representations.rb,
lib/google/apis/translate_v3/representations.rb

Overview

Configures which glossary is used for a specific target language and defines options for applying that glossary.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TranslateTextGlossaryConfig

Returns a new instance of TranslateTextGlossaryConfig.



2382
2383
2384
# File 'lib/google/apis/translate_v3/classes.rb', line 2382

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contextual_translation_enabledBoolean Also known as: contextual_translation_enabled?

Optional. If set to true, the glossary will be used for contextual translation. Corresponds to the JSON property contextualTranslationEnabled

Returns:

  • (Boolean)


2365
2366
2367
# File 'lib/google/apis/translate_v3/classes.rb', line 2365

def contextual_translation_enabled
  @contextual_translation_enabled
end

#glossaryString

Required. The glossary to be applied for this translation. The format depends on the glossary: - User-provided custom glossary: projects/project- number-or-id/locations/location-id/glossaries/glossary-id` Corresponds to the JSON propertyglossary`

Returns:

  • (String)


2373
2374
2375
# File 'lib/google/apis/translate_v3/classes.rb', line 2373

def glossary
  @glossary
end

#ignore_caseBoolean Also known as: ignore_case?

Optional. Indicates match is case insensitive. The default value is false if missing. Corresponds to the JSON property ignoreCase

Returns:

  • (Boolean)


2379
2380
2381
# File 'lib/google/apis/translate_v3/classes.rb', line 2379

def ignore_case
  @ignore_case
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2387
2388
2389
2390
2391
# File 'lib/google/apis/translate_v3/classes.rb', line 2387

def update!(**args)
  @contextual_translation_enabled = args[:contextual_translation_enabled] if args.key?(:contextual_translation_enabled)
  @glossary = args[:glossary] if args.key?(:glossary)
  @ignore_case = args[:ignore_case] if args.key?(:ignore_case)
end