Class: Google::Apis::TranslateV3::GlossaryEntry
- Inherits:
-
Object
- Object
- Google::Apis::TranslateV3::GlossaryEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/translate_v3/classes.rb,
lib/google/apis/translate_v3/representations.rb,
lib/google/apis/translate_v3/representations.rb
Overview
Represents a single entry in a glossary.
Instance Attribute Summary collapse
-
#description ⇒ String
Describes the glossary entry.
-
#name ⇒ String
Identifier.
-
#terms_pair ⇒ Google::Apis::TranslateV3::GlossaryTermsPair
Represents a single entry for an unidirectional glossary.
-
#terms_set ⇒ Google::Apis::TranslateV3::GlossaryTermsSet
Represents a single entry for an equivalent term set glossary.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GlossaryEntry
constructor
A new instance of GlossaryEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GlossaryEntry
Returns a new instance of GlossaryEntry.
1126 1127 1128 |
# File 'lib/google/apis/translate_v3/classes.rb', line 1126 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Describes the glossary entry.
Corresponds to the JSON property description
1106 1107 1108 |
# File 'lib/google/apis/translate_v3/classes.rb', line 1106 def description @description end |
#name ⇒ String
Identifier. The resource name of the entry. Format: projects/*/locations/*/
glossaries/*/glossaryEntries/*
Corresponds to the JSON property name
1112 1113 1114 |
# File 'lib/google/apis/translate_v3/classes.rb', line 1112 def name @name end |
#terms_pair ⇒ Google::Apis::TranslateV3::GlossaryTermsPair
Represents a single entry for an unidirectional glossary.
Corresponds to the JSON property termsPair
1117 1118 1119 |
# File 'lib/google/apis/translate_v3/classes.rb', line 1117 def terms_pair @terms_pair end |
#terms_set ⇒ Google::Apis::TranslateV3::GlossaryTermsSet
Represents a single entry for an equivalent term set glossary. This is used
for equivalent term sets where each term can be replaced by the other terms in
the set.
Corresponds to the JSON property termsSet
1124 1125 1126 |
# File 'lib/google/apis/translate_v3/classes.rb', line 1124 def terms_set @terms_set end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1131 1132 1133 1134 1135 1136 |
# File 'lib/google/apis/translate_v3/classes.rb', line 1131 def update!(**args) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @terms_pair = args[:terms_pair] if args.key?(:terms_pair) @terms_set = args[:terms_set] if args.key?(:terms_set) end |