Class: Google::Apis::TranslateV3::GlossaryTermsSet
- Inherits:
-
Object
- Object
- Google::Apis::TranslateV3::GlossaryTermsSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/translate_v3/classes.rb,
lib/google/apis/translate_v3/representations.rb,
lib/google/apis/translate_v3/representations.rb
Overview
Represents a single entry for an equivalent term set glossary. This is used for equivalent term sets where each term can be replaced by the other terms in the set.
Instance Attribute Summary collapse
-
#terms ⇒ Array<Google::Apis::TranslateV3::GlossaryTerm>
Each term in the set represents a term that can be replaced by the other terms.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GlossaryTermsSet
constructor
A new instance of GlossaryTermsSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GlossaryTermsSet
Returns a new instance of GlossaryTermsSet.
1219 1220 1221 |
# File 'lib/google/apis/translate_v3/classes.rb', line 1219 def initialize(**args) update!(**args) end |
Instance Attribute Details
#terms ⇒ Array<Google::Apis::TranslateV3::GlossaryTerm>
Each term in the set represents a term that can be replaced by the other terms.
Corresponds to the JSON property terms
1217 1218 1219 |
# File 'lib/google/apis/translate_v3/classes.rb', line 1217 def terms @terms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1224 1225 1226 |
# File 'lib/google/apis/translate_v3/classes.rb', line 1224 def update!(**args) @terms = args[:terms] if args.key?(:terms) end |