Class: Google::Apis::TranslateV3::RomanizeTextRequest
- Inherits:
-
Object
- Object
- Google::Apis::TranslateV3::RomanizeTextRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/translate_v3/classes.rb,
lib/google/apis/translate_v3/representations.rb,
lib/google/apis/translate_v3/representations.rb
Overview
The request message for synchronous romanization.
Instance Attribute Summary collapse
-
#contents ⇒ Array<String>
Required.
-
#source_language_code ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RomanizeTextRequest
constructor
A new instance of RomanizeTextRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RomanizeTextRequest
Returns a new instance of RomanizeTextRequest.
2076 2077 2078 |
# File 'lib/google/apis/translate_v3/classes.rb', line 2076 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ Array<String>
Required. The content of the input in string format.
Corresponds to the JSON property contents
2065 2066 2067 |
# File 'lib/google/apis/translate_v3/classes.rb', line 2065 def contents @contents end |
#source_language_code ⇒ String
Optional. The ISO-639 language code of the input text if known, for example, "
hi" or "zh". Supported language codes are listed in Language Support. If the source language isn't
specified, the API attempts to identify the source language automatically and
returns the source language for each content in the response.
Corresponds to the JSON property sourceLanguageCode
2074 2075 2076 |
# File 'lib/google/apis/translate_v3/classes.rb', line 2074 def source_language_code @source_language_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2081 2082 2083 2084 |
# File 'lib/google/apis/translate_v3/classes.rb', line 2081 def update!(**args) @contents = args[:contents] if args.key?(:contents) @source_language_code = args[:source_language_code] if args.key?(:source_language_code) end |